import React from 'react';
export declare type Size = 'slim' | 'medium' | 'large';
export declare type TextAlign = 'left' | 'right' | 'center';
export interface ButtonProps {
    /** The content to display inside the button */
    children?: React.ReactNode | React.ReactElement;
    /** A destination to link to, rendered in the href attribute of a link */
    url?: string;
    /** A unique identifier for the button */
    id?: string;
    /** Provides extra visual weight and identifies the primary action in a set of buttons */
    primary?: boolean;
    secondary?: boolean;
    /** Indicates a dangerous or potentially negative action */
    destructive?: boolean;
    /** Disables the button, disallowing merchant interaction */
    disabled?: boolean;
    /** Replaces button text with a spinner while a background action is being performed */
    loading?: boolean;
    /**
     * Changes the size of the button, giving it more or less padding
     * @default 'medium'
     */
    size?: Size;
    /** Changes the inner text alignment of the button */
    textAlign?: TextAlign;
    /** Gives the button a subtle alternative to the default button styling, appropriate for certain backdrops */
    outline?: boolean;
    /** Gives the button the appearance of being pressed */
    pressed?: boolean;
    /** Allows the button to grow to the width of its container */
    fullWidth?: boolean;
    /** Allows the button to submit a form */
    submit?: boolean;
    /** Renders a button that looks like a link */
    plain?: boolean;
    /** Makes `plain` and `outline` Button colors (text, borders, icons) the same as the current text color. Also adds an underline to `plain` Buttons */
    monochrome?: boolean;
    /** Forces url to open in a new tab */
    external?: boolean;
    /** Visually hidden text for screen readers */
    accessibilityLabel?: string;
    /** Callback when clicked */
    onClick?(): void;
    /** Callback when button becomes focussed */
    onFocus?(): void;
    /** Callback when focus leaves button */
    onBlur?(): void;
}
export declare const Button: ({ id, url, disabled, loading, children, accessibilityLabel, onClick, onFocus, onBlur, external, primary, outline, destructive, plain, monochrome, secondary, submit, size, textAlign, fullWidth, pressed, }: ButtonProps) => JSX.Element;
