'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = require('react');
var React__default = _interopDefault(React);
var styled = _interopDefault(require('@emotion/styled'));
var polished = require('polished');
var dates = require('@shopify/javascript-utilities/dates');

/*! *****************************************************************************
Copyright (c) Microsoft Corporation. All rights reserved.
Licensed under the Apache License, Version 2.0 (the "License"); you may not use
this file except in compliance with the License. You may obtain a copy of the
License at http://www.apache.org/licenses/LICENSE-2.0

THIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
KIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED
WARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,
MERCHANTABLITY OR NON-INFRINGEMENT.

See the Apache Version 2.0 License for specific language governing permissions
and limitations under the License.
***************************************************************************** */

var __assign = function() {
    __assign = Object.assign || function __assign(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};

function __spreadArrays() {
    for (var s = 0, i = 0, il = arguments.length; i < il; i++) s += arguments[i].length;
    for (var r = Array(s), k = 0, i = 0; i < il; i++)
        for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
            r[k] = a[j];
    return r;
}
function __makeTemplateObject(cooked, raw) {
    if (Object.defineProperty) { Object.defineProperty(cooked, "raw", { value: raw }); } else { cooked.raw = raw; }
    return cooked;
}

var base = '#E0E5EC';
var lighter = '#FFFFFF';
var darker = '#7489a9';
var primary = '#3C00AB';
var danger = '#E92D48';
var secondary = '#191b32';
var minor = '#c7d3e4';
var colorMap = function (state) {
    switch (state) {
        case 'primary':
            return primary;
        case 'destructive':
            return danger;
        case 'secondary':
            return secondary;
        default:
            return darker;
    }
};

var shadowDefault = "-4px -4px 14px " + lighter + ", 4px 4px 14px " + darker + ", -1px -1px 2px " + lighter + ", 1px 1px 2px " + darker;
var shadowLite = "-1px -1px 1px " + lighter + ", 1px 1px 1px " + darker;
var shadowInset = "1px 1px 3px " + darker + " inset, -1px -1px 3px " + lighter + " inset,\n-1px -1px 1px " + darker + ", 1px 1px 1px " + lighter;
var shadowErrorInset = "0 0 2px " + danger + " inset,\n0 0 1px 1px " + danger;
var shadowScaled = "-8px -8px 20px " + lighter + ", 8px 8px 20px " + darker + ", -1px -1px 0px " + lighter + ", 1px 1px 0px " + darker;

var RADIUS = '6px'; // ToDo: Should be provided from theme configure
var stateString = function (props) {
    if (props.primary)
        return 'primary';
    if (props.secondary)
        return 'secondary';
    if (props.destructive)
        return 'destructive';
    if (props.disabled)
        return 'disabled';
};
var rippleStyle = function (color) { return "\n\n  position: relative;\n  overflow: hidden;\n  transform: translate3d(0, 0, 0);\n\n  &:after {\n    content: \"\";\n    display: block;\n    position: absolute;\n    width: 100%;\n    height: 100%;\n    top: 0;\n    left: 0;\n    pointer-events: none;\n    background-image: radial-gradient(circle, " + polished.darken(0.1, color || darker) + " 10%, transparent 10.01%);\n    background-repeat: no-repeat;\n    background-position: 50%;\n    transform: scale(10,10);\n    opacity: 0;\n    transition: transform .5s, opacity 1s;\n  }\n\n  &:active:after {\n    transform: scale(0,0);\n    opacity: .2;\n    transition: 0s;\n  }\n"; };
var styleWithProps = function (props) { return "\n  background: " + background(props) + "\n  border: unset;\n  border-radius: " + RADIUS + ";\n  box-shadow: " + boxShadow(props) + "\n  color: " + fontColor(props) + ";\n  cursor: pointer;\n  font-size: 16px;\n  font-weight: normal;\n  outline: unset;\n  padding: " + paddingSize(props.size) + ";\n  pointer-events: " + (props.disabled ? ' none' : 'unset') + ";\n  transition-duration: 0.3s;\n  transition-timing-function: ease-in;\n  \n  " + rippleStyle(stateString(props) ? colorMap(stateString(props)) : undefined) + "\n"; };
var styleFeedbackWithProps = function (props) { return "\n  box-shadow: " + (props.pressed
    ? "\n      0px 0px 0px " + darker + " inset, 0 0 0 " + lighter + " inset, " + shadowScaled + ";"
    : shadowScaled + ";") + "\n  transition-duration: 0.2s;\n  transition-timing-function: ease-oun;\n"; };
var paddingSize = function (s) {
    switch (s) {
        case 'slim':
            return '4px 8px;';
        case 'large':
            return '16px 24px;';
        default:
            return '10px 16px;';
    }
};
var background = function (props) {
    if (props.disabled) {
        return minor + ";";
    }
    if (props.plain) {
        return 'unset;';
    }
    if (props.destructive) {
        return danger + ";";
    }
    if (props.primary) {
        return primary + ";";
    }
    if (props.secondary) {
        return secondary + ";";
    }
    if (props.outline) {
        return base + ";";
    }
    return base + ";";
};
var fontColor = function (props) {
    if (props.disabled) {
        return darker + ";";
    }
    if (props.destructive || props.primary || props.secondary) {
        return "#fff;";
    }
    return polished.darken(0.1, darker) + ";";
};
var boxShadow = function (props) {
    if (props.plain) {
        return 'unset;';
    }
    if (props.outline) {
        return shadowLite + ";";
    }
    if (props.pressed) {
        return shadowInset + ";";
    }
    if (props.disabled) {
        return "unset;";
    }
    return shadowDefault + ";";
};
var StyledButton = styled.button(templateObject_1 || (templateObject_1 = __makeTemplateObject(["\n  ", "\n  &:hover {\n    ", "\n  }\n"], ["\n  ", "\n  &:hover {\n    ", "\n  }\n"])), function (props) { return styleWithProps(props); }, function (props) { return styleFeedbackWithProps(props); });
var StyledAnchor = styled.a(templateObject_2 || (templateObject_2 = __makeTemplateObject(["\n  ", "\n  text-decolation: none;\n  &:hover {\n    ", "\n  }\n"], ["\n  ", "\n  text-decolation: none;\n  &:hover {\n    ", "\n  }\n"])), function (props) { return styleWithProps(props); }, function (props) { return styleFeedbackWithProps(props); });
var templateObject_1, templateObject_2;

var DEFAULT_SIZE = 'medium';
var Button = function (_a) {
    var id = _a.id, url = _a.url, disabled = _a.disabled, loading = _a.loading, children = _a.children, accessibilityLabel = _a.accessibilityLabel, onClick = _a.onClick, onFocus = _a.onFocus, onBlur = _a.onBlur, external = _a.external, primary = _a.primary, outline = _a.outline, destructive = _a.destructive, plain = _a.plain, monochrome = _a.monochrome, secondary = _a.secondary, submit = _a.submit, _b = _a.size, size = _b === void 0 ? DEFAULT_SIZE : _b, textAlign = _a.textAlign, fullWidth = _a.fullWidth, pressed = _a.pressed;
    var isDisabled = disabled || loading;
    var childMarkup = children ? React__default.createElement(React__default.Fragment, null, children) : null;
    var content = React__default.createElement(React__default.Fragment, null, childMarkup);
    var type = submit ? 'submit' : 'button';
    var buttonMarkup;
    if (url) {
        buttonMarkup = isDisabled ? (React__default.createElement("a", { id: id, "aria-label": accessibilityLabel }, content)) : (React__default.createElement(StyledAnchor, { size: size, id: id, href: url, target: external ? '_blank' : '', plain: plain, primary: primary, secondary: secondary, pressed: pressed, outline: outline, textAlign: textAlign, destructive: destructive, onClick: onClick, onFocus: onFocus, onBlur: onBlur, "aria-label": accessibilityLabel }, content));
    }
    else {
        buttonMarkup = (React__default.createElement(StyledButton, { size: size, secondary: secondary, id: id, type: type, onClick: onClick, onFocus: onFocus, onBlur: onBlur, plain: plain, primary: primary, pressed: pressed, outline: outline, textAlign: textAlign, destructive: destructive, disabled: isDisabled, "aria-label": accessibilityLabel, role: loading ? 'alert' : undefined, "aria-busy": loading ? true : undefined }, content));
    }
    return buttonMarkup;
};

var Key;
(function (Key) {
    Key[Key["Backspace"] = 8] = "Backspace";
    Key[Key["Tab"] = 9] = "Tab";
    Key[Key["Enter"] = 13] = "Enter";
    Key[Key["Shift"] = 16] = "Shift";
    Key[Key["Ctrl"] = 17] = "Ctrl";
    Key[Key["Alt"] = 18] = "Alt";
    Key[Key["Pause"] = 19] = "Pause";
    Key[Key["CapsLock"] = 20] = "CapsLock";
    Key[Key["Escape"] = 27] = "Escape";
    Key[Key["Space"] = 32] = "Space";
    Key[Key["PageUp"] = 33] = "PageUp";
    Key[Key["PageDown"] = 34] = "PageDown";
    Key[Key["End"] = 35] = "End";
    Key[Key["Home"] = 36] = "Home";
    Key[Key["LeftArrow"] = 37] = "LeftArrow";
    Key[Key["UpArrow"] = 38] = "UpArrow";
    Key[Key["RightArrow"] = 39] = "RightArrow";
    Key[Key["DownArrow"] = 40] = "DownArrow";
    Key[Key["Insert"] = 45] = "Insert";
    Key[Key["Delete"] = 46] = "Delete";
    Key[Key["Key0"] = 48] = "Key0";
    Key[Key["Key1"] = 49] = "Key1";
    Key[Key["Key2"] = 50] = "Key2";
    Key[Key["Key3"] = 51] = "Key3";
    Key[Key["Key4"] = 52] = "Key4";
    Key[Key["Key5"] = 53] = "Key5";
    Key[Key["Key6"] = 54] = "Key6";
    Key[Key["Key7"] = 55] = "Key7";
    Key[Key["Key8"] = 56] = "Key8";
    Key[Key["Key9"] = 57] = "Key9";
    Key[Key["KeyA"] = 65] = "KeyA";
    Key[Key["KeyB"] = 66] = "KeyB";
    Key[Key["KeyC"] = 67] = "KeyC";
    Key[Key["KeyD"] = 68] = "KeyD";
    Key[Key["KeyE"] = 69] = "KeyE";
    Key[Key["KeyF"] = 70] = "KeyF";
    Key[Key["KeyG"] = 71] = "KeyG";
    Key[Key["KeyH"] = 72] = "KeyH";
    Key[Key["KeyI"] = 73] = "KeyI";
    Key[Key["KeyJ"] = 74] = "KeyJ";
    Key[Key["KeyK"] = 75] = "KeyK";
    Key[Key["KeyL"] = 76] = "KeyL";
    Key[Key["KeyM"] = 77] = "KeyM";
    Key[Key["KeyN"] = 78] = "KeyN";
    Key[Key["KeyO"] = 79] = "KeyO";
    Key[Key["KeyP"] = 80] = "KeyP";
    Key[Key["KeyQ"] = 81] = "KeyQ";
    Key[Key["KeyR"] = 82] = "KeyR";
    Key[Key["KeyS"] = 83] = "KeyS";
    Key[Key["KeyT"] = 84] = "KeyT";
    Key[Key["KeyU"] = 85] = "KeyU";
    Key[Key["KeyV"] = 86] = "KeyV";
    Key[Key["KeyW"] = 87] = "KeyW";
    Key[Key["KeyX"] = 88] = "KeyX";
    Key[Key["KeyY"] = 89] = "KeyY";
    Key[Key["KeyZ"] = 90] = "KeyZ";
    Key[Key["LeftMeta"] = 91] = "LeftMeta";
    Key[Key["RightMeta"] = 92] = "RightMeta";
    Key[Key["Select"] = 93] = "Select";
    Key[Key["Numpad0"] = 96] = "Numpad0";
    Key[Key["Numpad1"] = 97] = "Numpad1";
    Key[Key["Numpad2"] = 98] = "Numpad2";
    Key[Key["Numpad3"] = 99] = "Numpad3";
    Key[Key["Numpad4"] = 100] = "Numpad4";
    Key[Key["Numpad5"] = 101] = "Numpad5";
    Key[Key["Numpad6"] = 102] = "Numpad6";
    Key[Key["Numpad7"] = 103] = "Numpad7";
    Key[Key["Numpad8"] = 104] = "Numpad8";
    Key[Key["Numpad9"] = 105] = "Numpad9";
    Key[Key["Multiply"] = 106] = "Multiply";
    Key[Key["Add"] = 107] = "Add";
    Key[Key["Subtract"] = 109] = "Subtract";
    Key[Key["Decimal"] = 110] = "Decimal";
    Key[Key["Divide"] = 111] = "Divide";
    Key[Key["F1"] = 112] = "F1";
    Key[Key["F2"] = 113] = "F2";
    Key[Key["F3"] = 114] = "F3";
    Key[Key["F4"] = 115] = "F4";
    Key[Key["F5"] = 116] = "F5";
    Key[Key["F6"] = 117] = "F6";
    Key[Key["F7"] = 118] = "F7";
    Key[Key["F8"] = 119] = "F8";
    Key[Key["F9"] = 120] = "F9";
    Key[Key["F10"] = 121] = "F10";
    Key[Key["F11"] = 122] = "F11";
    Key[Key["F12"] = 123] = "F12";
    Key[Key["NumLock"] = 144] = "NumLock";
    Key[Key["ScrollLock"] = 145] = "ScrollLock";
    Key[Key["Semicolon"] = 186] = "Semicolon";
    Key[Key["Equals"] = 187] = "Equals";
    Key[Key["Comma"] = 188] = "Comma";
    Key[Key["Dash"] = 189] = "Dash";
    Key[Key["Period"] = 190] = "Period";
    Key[Key["ForwardSlash"] = 191] = "ForwardSlash";
    Key[Key["GraveAccent"] = 192] = "GraveAccent";
    Key[Key["OpenBracket"] = 219] = "OpenBracket";
    Key[Key["BackSlash"] = 220] = "BackSlash";
    Key[Key["CloseBracket"] = 221] = "CloseBracket";
    Key[Key["SingleQuote"] = 222] = "SingleQuote";
})(Key || (Key = {}));
var TypeOf;
(function (TypeOf) {
    TypeOf["Undefined"] = "undefined";
    TypeOf["Object"] = "object";
    TypeOf["Boolean"] = "boolean";
    TypeOf["Number"] = "number";
    TypeOf["String"] = "string";
    TypeOf["Symbol"] = "symbol";
    TypeOf["Function"] = "function";
})(TypeOf || (TypeOf = {}));

var boxShadow$1 = function (props) {
    if (props.disabled) {
        return "0 0 0 1px " + polished.darken(0.2, base) + " inset";
    }
    if (props.error) {
        return shadowErrorInset;
    }
    return shadowInset;
};
var color = function (props) {
    if (props.error) {
        return danger;
    }
    return polished.darken(0.1, darker);
};
var placeholder = function (props) {
    if (props.error) {
        return danger;
    }
    return polished.darken(0.1, base);
};
var commonStyle = function (props) { return "\n  border: unset;\n  border-radius: 6px;\n  box-sizing: border-box;\n  box-shadow: " + boxShadow$1(props) + ";\n  background: " + (props.disabled ? base : '#fff') + ";\n  color: " + color(props) + ";\n  font-size: 16px;\n  padding: 8px;\n  transition: 0.3s;\n  width: 100%;\n  ::placeholder,\n  ::-webkit-input-placeholder {\n    color: " + placeholder(props) + ";\n  }\n  :-ms-input-placeholder {\n     color: " + placeholder(props) + ";\n  }\n  &:focus {\n    outline: unset;\n    box-shadow: " + (props.error
    ? "0 0 0 " + danger + " inset, 0 0 0 " + lighter + " inset, 0 0 5px " + danger
    : "0 0 0 " + darker + " inset, 0 0 0 " + lighter + " inset, 0 0 5px " + primary) + ";\n  }\n"; };
var Input = styled.input(templateObject_1$1 || (templateObject_1$1 = __makeTemplateObject(["\n  ", "\n"], ["\n  ", "\n"])), function (props) { return commonStyle(props); });
var TextArea = styled.textarea(templateObject_2$1 || (templateObject_2$1 = __makeTemplateObject(["\n  ", "\n"], ["\n  ", "\n"])), function (props) { return commonStyle(props); });
var Label = styled.p(templateObject_3 || (templateObject_3 = __makeTemplateObject(["\n  color: ", ";\n  transition: 0.3s;\n  font-size: 14px;\n  margin: 0;\n"], ["\n  color: ", ";\n  transition: 0.3s;\n  font-size: 14px;\n  margin: 0;\n"])), function (props) { return (props.error ? danger : polished.darken(0.3, darker)); });
var Container = styled.label(templateObject_4 || (templateObject_4 = __makeTemplateObject(["\n  width: auto;\n"], ["\n  width: auto;\n"])));
var FieldContainer = styled.div(templateObject_5 || (templateObject_5 = __makeTemplateObject(["\n  position: relative;\n"], ["\n  position: relative;\n"])));
var HelpText = styled.p(templateObject_6 || (templateObject_6 = __makeTemplateObject(["\n  font-size: 12px;\n  color: ", ";\n  margin: 3px 0 0;\n"], ["\n  font-size: 12px;\n  color: ", ";\n  margin: 3px 0 0;\n"])), function (props) { return color(props); });
var templateObject_1$1, templateObject_2$1, templateObject_3, templateObject_4, templateObject_5, templateObject_6;

var TextField = function (_a) {
    var prefix = _a.prefix, suffix = _a.suffix, placeholder = _a.placeholder, value = _a.value, helpText = _a.helpText, label = _a.label, labelHidden = _a.labelHidden, disabled = _a.disabled, readOnly = _a.readOnly, autoFocus = _a.autoFocus, focused = _a.focused, multiline = _a.multiline, error = _a.error, type = _a.type, name = _a.name, idProp = _a.id, role = _a.role, step = _a.step, autoComplete = _a.autoComplete, max = _a.max, maxLength = _a.maxLength, min = _a.min, minLength = _a.minLength, pattern = _a.pattern, spellCheck = _a.spellCheck, ariaOwns = _a.ariaOwns, ariaControls = _a.ariaControls, ariaActiveDescendant = _a.ariaActiveDescendant, ariaAutocomplete = _a.ariaAutocomplete, onChange = _a.onChange, onFocus = _a.onFocus, onBlur = _a.onBlur;
    var _b = React.useState(null), height = _b[0], setHeight = _b[1];
    var _c = React.useState(Boolean(focused)), focus = _c[0], setFocus = _c[1];
    var id = "TextField" + new Date().getMilliseconds;
    var inputRef = React.useRef(null);
    var prefixRef = React.useRef(null);
    var suffixRef = React.useRef(null);
    React.useEffect(function () {
        var input = inputRef.current;
        if (!input || focused === undefined)
            return;
        focused ? input.focus() : input.blur();
    }, [focused]);
    // Use a typeof check here as Typescript mostly protects us from non-stringy
    // values but overzealous usage of `any` in consuming apps means people have
    // been known to pass a number in, so make it clear that doesn't work.
    var normalizedValue = typeof value === 'string' ? value : '';
    var inputType = type === 'currency' ? 'text' : type;
    var prefixMarkup = prefix ? (React__default.createElement("div", { id: id + "Prefix", ref: prefixRef }, prefix)) : null;
    var suffixMarkup = suffix ? (React__default.createElement("div", { id: id + "Suffix", ref: suffixRef }, suffix)) : null;
    var describedBy = [];
    if (error) {
        describedBy.push(id + "Error");
    }
    var labelledBy = [];
    if (prefix) {
        labelledBy.push(id + "Prefix");
    }
    if (suffix) {
        labelledBy.push(id + "Suffix");
    }
    var textareaProps = {
        name: name,
        id: id,
        disabled: disabled,
        readOnly: readOnly,
        role: role,
        autoFocus: autoFocus,
        'error': Boolean(error),
        'value': normalizedValue,
        placeholder: placeholder,
        onFocus: onFocus,
        onBlur: onBlur,
        'onKeyPress': handleKeyPress,
        'onChange': handleTextAreaChange,
        min: min,
        max: max,
        step: step,
        minLength: minLength,
        maxLength: maxLength,
        spellCheck: spellCheck,
        pattern: pattern,
        'type': inputType,
        'aria-describedby': describedBy.length ? describedBy.join(' ') : undefined,
        'aria-labelledby': labelledBy.join(' '),
        'aria-invalid': Boolean(error),
        'aria-owns': ariaOwns,
        'aria-activedescendant': ariaActiveDescendant,
        'aria-controls': ariaControls,
    };
    var inputProps = {
        name: name,
        id: id,
        disabled: disabled,
        readOnly: readOnly,
        role: role,
        autoFocus: autoFocus,
        'error': Boolean(error),
        'value': normalizedValue,
        placeholder: placeholder,
        onFocus: onFocus,
        onBlur: onBlur,
        'onKeyPress': handleKeyPress,
        'onChange': handleInputChange,
        min: min,
        max: max,
        step: step,
        minLength: minLength,
        maxLength: maxLength,
        spellCheck: spellCheck,
        pattern: pattern,
        'type': inputType,
        'aria-describedby': describedBy.length ? describedBy.join(' ') : undefined,
        'aria-labelledby': labelledBy.join(' '),
        'aria-invalid': Boolean(error),
        'aria-owns': ariaOwns,
        'aria-activedescendant': ariaActiveDescendant,
        'aria-controls': ariaControls,
    };
    var textarea = React__default.createElement(TextArea, __assign({}, textareaProps));
    var input = React__default.createElement(Input, __assign({}, inputProps));
    return (React__default.createElement(Container, null,
        label && !labelHidden ? (React__default.createElement(Label, { error: Boolean(error) }, label)) : null,
        React__default.createElement(FieldContainer, { onFocus: handleFocus, onBlur: handleBlur, onClick: handleClick },
            prefixMarkup,
            multiline ? textarea : input,
            suffixMarkup),
        React__default.createElement(HelpText, { error: Boolean(error) }, helpText)));
    function handleKeyPress(event) {
        var key = event.key, which = event.which;
        var numbersSpec = /[\d.eE+-]$/;
        if (type !== 'number' || which === Key.Enter || numbersSpec.test(key)) {
            return;
        }
        event.preventDefault();
    }
    function containsAffix(target) {
        return (target instanceof HTMLElement &&
            ((prefixRef.current && prefixRef.current.contains(target)) ||
                (suffixRef.current && suffixRef.current.contains(target))));
    }
    function handleInputChange(event) {
        onChange && onChange(event.currentTarget.value, id);
    }
    function handleTextAreaChange(event) {
        onChange && onChange(event.currentTarget.value, id);
    }
    function handleFocus(_a) {
        var target = _a.target;
        if (containsAffix(target)) {
            return;
        }
        setFocus(true);
    }
    function handleBlur() {
        setFocus(false);
    }
    function handleClick(_a) {
        var target = _a.target;
        if (containsAffix(target)) {
            return;
        }
        inputRef.current && inputRef.current.focus();
    }
};

// Wraps `element` in `Component`, if it is not already an instance of
// `Component`. If `props` is passed, those will be added as props on the
// wrapped component. If `element` is null, the component is not wrapped.
function wrapWithComponent(element, Component, props) {
    if (element == null) {
        return null;
    }
    return isElementOfType(element, Component) ? (element) : (React__default.createElement(Component, __assign({}, props), element));
}
// In development, we compare based on the name of the function because
// React Hot Loader proxies React components in order to make updates. In
// production we can simply compare the components for equality.
var isComponent = process.env.NODE_ENV === 'development'
    ? hotReloadComponentCheck
    : function (AComponent, AnotherComponent) { return AComponent === AnotherComponent; };
// Checks whether `element` is a React element of type `Component` (or one of
// the passed components, if `Component` is an array of React components).
function isElementOfType(element, Component) {
    if (element == null ||
        !React__default.isValidElement(element) ||
        typeof element.type === 'string') {
        return false;
    }
    var type = element.type;
    var Components = Array.isArray(Component) ? Component : [Component];
    return Components.some(function (AComponent) { return typeof type !== 'string' && isComponent(AComponent, type); });
}
// Returns all children that are valid elements as an array. Can optionally be
// filtered by passing `predicate`.
function elementChildren(children, predicate) {
    if (predicate === void 0) { predicate = function () { return true; }; }
    return React__default.Children.toArray(children).filter(function (child) { return React__default.isValidElement(child) && predicate(child); });
}
function hotReloadComponentCheck(AComponent, AnotherComponent) {
    var componentName = AComponent.name;
    var anotherComponentName = AnotherComponent.displayName;
    return (AComponent === AnotherComponent ||
        (Boolean(componentName) && componentName === anotherComponentName));
}

var BASE_SPACING = 14;
var alignmentMap = function (alignment) {
    switch (alignment) {
        case 'leading':
            return 'align-items: flex-start';
        case 'trailing':
            return 'align-items: flex-end';
        case 'center':
            return 'align-items: center';
        case 'fill':
            return 'align-items: stretch';
        case 'baseline':
            return 'align-items: baseline';
    }
};
var distributionMap = function (distribution) {
    switch (distribution) {
        case 'leading':
            return 'justify-content: flex-start';
        case 'trailing':
            return 'justify-content: flex-end';
        case 'center':
            return 'justify-content: center';
        case 'fill':
            return 'flex: 1 1 auto';
        case 'equalSpacing':
            return 'justify-content: space-between';
        case 'fillEvenly':
            return 'flex: 1 1 auto';
    }
};
var Stack = styled.div(templateObject_1$2 || (templateObject_1$2 = __makeTemplateObject(["\n  align-items: stretch;\n  display: flex;\n  ", ";\n  ", ";\n  flex-wrap: ", ";\n  margin-top: ", "px;\n  margin-left: ", "px;\n  flex-direction: ", ";\n  > .Item {\n    margin-top: ", "px;\n    margin-left: ", "px;\n    max-width: 100%;\n  }\n"], ["\n  align-items: stretch;\n  display: flex;\n  ", ";\n  ", ";\n  flex-wrap: ", ";\n  margin-top: ", "px;\n  margin-left: ", "px;\n  flex-direction: ", ";\n  > .Item {\n    margin-top: ", "px;\n    margin-left: ", "px;\n    max-width: 100%;\n  }\n"])), function (props) { return (props.alignment ? alignmentMap(props.alignment) : null); }, function (props) { return (props.distribution ? distributionMap(props.distribution) : null); }, function (props) { return (props.noWrap ? 'nowrap' : 'wrap'); }, -1 * BASE_SPACING, -1 * BASE_SPACING, function (props) { return (props.vertical ? 'column' : 'row'); }, BASE_SPACING, BASE_SPACING);
var templateObject_1$2;

var BASE_SPACING$1 = 14;
var ItemComponent = styled.div(templateObject_1$3 || (templateObject_1$3 = __makeTemplateObject(["\n  flex: ", ";\n  min-width: 0;\n  margin-top: ", "px;\n  margin-left: ", "px;\n  max-width: 100%;\n"], ["\n  flex: ", ";\n  min-width: 0;\n  margin-top: ", "px;\n  margin-left: ", "px;\n  max-width: 100%;\n"])), function (props) { return (props.fill ? '1 1 auto' : '0 0 auto'); }, BASE_SPACING$1, BASE_SPACING$1);
function Item(_a) {
    var children = _a.children, fill = _a.fill;
    return React__default.createElement(ItemComponent, { fill: fill ? 1 : 0 }, children);
}
var templateObject_1$3;

var Stack$1 = React.memo(function Stack$1(_a) {
    var children = _a.children, vertical = _a.vertical, distribution = _a.distribution, alignment = _a.alignment, wrap = _a.wrap;
    var itemMarkup = elementChildren(children).map(function (child, index) {
        var props = { key: index };
        return wrapWithComponent(child, Item, props);
    });
    return (React__default.createElement(Stack, { vertical: vertical || false, alignment: alignment, distribution: distribution, noWrap: wrap || false }, itemMarkup));
});
Stack$1.Item = Item;

var extraTight = 4;
var tight = 8;
var base$1 = 16;

var FONT_SIZE = 12;
var ZINDEX_SELECTED = 30;
var DatePickerContainer = styled.div(templateObject_1$4 || (templateObject_1$4 = __makeTemplateObject(["\n  position: relative;\n"], ["\n  position: relative;\n"])));
var MonthContainer = styled.div(templateObject_2$2 || (templateObject_2$2 = __makeTemplateObject(["\n  display: flex;\n  flex-wrap: wrap;\n  margin-top: ", "px;\n  margin-left: ", "px;\n"], ["\n  display: flex;\n  flex-wrap: wrap;\n  margin-top: ", "px;\n  margin-left: ", "px;\n"])), -1 * base$1, -1 * base$1);
var MonthStyled = styled.div(templateObject_3$1 || (templateObject_3$1 = __makeTemplateObject(["\n  flex: 1 1 auto;\n  margin-top: ", "px;\n  margin-left: ", "px;\n  max-width: calc(100% - ", "px);\n  min-width: 200px;\n  font-weight: ", ";\n"], ["\n  flex: 1 1 auto;\n  margin-top: ", "px;\n  margin-left: ", "px;\n  max-width: calc(100% - ", "px);\n  min-width: 200px;\n  font-weight: ", ";\n"])), base$1, base$1, base$1, function (props) { return (props.current ? 700 : 400); });
var WeekStyled = styled.div(templateObject_4$1 || (templateObject_4$1 = __makeTemplateObject(["\n  display: flex;\n  margin-top: -1px;\n  &:first {\n    margin-top: 0;\n  }\n"], ["\n  display: flex;\n  margin-top: -1px;\n  &:first {\n    margin-top: 0;\n  }\n"])));
var WeeksContainer = styled.div(templateObject_5$1 || (templateObject_5$1 = __makeTemplateObject(["\n  border-radius: 8px;\n  box-shadow: 1px 1px 3px ", ", -1px -1px 3px ", ";\n  overflow: hidden;\n  transition-duration: 0.3s;\n  &:hover {\n    box-shadow: 4px 4px 10px ", ", -4px -4px 10px ", ",\n      -1px -1px 0px ", ", 1px 1px 0px ", ";\n  }\n"], ["\n  border-radius: 8px;\n  box-shadow: 1px 1px 3px ", ", -1px -1px 3px ", ";\n  overflow: hidden;\n  transition-duration: 0.3s;\n  &:hover {\n    box-shadow: 4px 4px 10px ", ", -4px -4px 10px ", ",\n      -1px -1px 0px ", ", 1px 1px 0px ", ";\n  }\n"])), polished.lighten(0.1, darker), lighter, polished.lighten(0.1, darker), lighter, lighter, darker);
var WeekHeadings = styled.div(templateObject_6$1 || (templateObject_6$1 = __makeTemplateObject(["\n  display: flex;\n"], ["\n  display: flex;\n"])));
var stateHandler = function (props, normal, selected, disabled) {
    if (props.selected) {
        return selected;
    }
    if (props.disabled) {
        return disabled;
    }
    return normal;
};
var DayContainer = styled.div(templateObject_7 || (templateObject_7 = __makeTemplateObject(["\n  position: relative;\n  flex: 1 0 0%;\n  width: ", "%;\n  margin: 0;\n"], ["\n  position: relative;\n  flex: 1 0 0%;\n  width: ", "%;\n  margin: 0;\n"])), 100 / 7);
var DayStyled = styled.button(templateObject_8 || (templateObject_8 = __makeTemplateObject(["\n  display: block;\n  padding: ", "px;\n  color: ", ";\n  background: ", ";\n  border: unset;\n  outline: none;\n  font-size: ", "px;\n  font-weight: ", ";\n  height: 100%;\n  text-align: center;\n  cursor: ", ";\n  z-index: ", ";\n  transition: 0.3s;\n  position: relative;\n  width: 100%;\n  &:first {\n    margin-left: 0;\n  }\n  &:hover {\n    color: #fff;\n    background: ", ";\n    border-color: ", ";\n  }\n"], ["\n  display: block;\n  padding: ", "px;\n  color: ", ";\n  background: ", ";\n  border: unset;\n  outline: none;\n  font-size: ", "px;\n  font-weight: ", ";\n  height: 100%;\n  text-align: center;\n  cursor: ", ";\n  z-index: ", ";\n  transition: 0.3s;\n  position: relative;\n  width: 100%;\n  &:first {\n    margin-left: 0;\n  }\n  &:hover {\n    color: #fff;\n    background: ", ";\n    border-color: ", ";\n  }\n"])), tight, function (props) { return stateHandler(props, 'inherit', '#fff', darker); }, function (props) { return stateHandler(props, 'transparent', secondary, '#ddd'); }, FONT_SIZE, function (props) { return (props.today ? 700 : 400); }, function (props) { return (props.disabled ? 'default' : 'pointer'); }, function (props) { return (props.selected ? ZINDEX_SELECTED : 1); }, polished.darken(0.15, darker), primary);
var DayShadowLayer = styled.div(templateObject_9 || (templateObject_9 = __makeTemplateObject(["\n  width: 100%;\n  height: 100%;\n  position: absolute;\n  box-shadow: -4px -4px 12px ", ", 4px 4px 12px ", ",\n    -1px -1px 0px ", ", 1px 1px 0px ", ";\n  content: '';\n  display: block;\n  top: 0;\n  left: 0;\n  z-index: -2;\n"], ["\n  width: 100%;\n  height: 100%;\n  position: absolute;\n  box-shadow: -4px -4px 12px ", ", 4px 4px 12px ", ",\n    -1px -1px 0px ", ", 1px 1px 0px ", ";\n  content: '';\n  display: block;\n  top: 0;\n  left: 0;\n  z-index: -2;\n"])), lighter, darker, lighter, darker);
var EmptyDay = styled.div(templateObject_10 || (templateObject_10 = __makeTemplateObject(["\n  display: block;\n  flex: 1 0 0%;\n  width: ", "%;\n  margin: 0;\n  padding: ", "px;\n  &:first {\n    margin-left: 0;\n  }\n"], ["\n  display: block;\n  flex: 1 0 0%;\n  width: ", "%;\n  margin: 0;\n  padding: ", "px;\n  &:first {\n    margin-left: 0;\n  }\n"])), 100 / 7, tight);
var WeekdayStyled = styled.div(templateObject_11 || (templateObject_11 = __makeTemplateObject(["\n  display: block;\n  flex: 1 0 0%;\n  padding: ", "px;\n  background: transparent;\n  font-size: ", "px;\n  text-align: center;\n  color: ", ";\n  font-weight: ", ";\n"], ["\n  display: block;\n  flex: 1 0 0%;\n  padding: ", "px;\n  background: transparent;\n  font-size: ", "px;\n  text-align: center;\n  color: ",
    ";\n  font-weight: ", ";\n"])), tight, FONT_SIZE, function (props) {
    return props.current ? polished.darken(0.3, darker) : polished.darken(0.2, darker);
}, function (props) { return (props.current ? 700 : 400); });
var Header = styled.div(templateObject_12 || (templateObject_12 = __makeTemplateObject(["\n  position: absolute;\n  top: ", "px;\n  display: flex;\n  justify-content: space-between;\n  width: 100%;\n"], ["\n  position: absolute;\n  top: ", "px;\n  display: flex;\n  justify-content: space-between;\n  width: 100%;\n"])), base$1);
var Title = styled.div(templateObject_13 || (templateObject_13 = __makeTemplateObject(["\n  flex: 1 1 auto;\n  color: ", ";\n  margin-top: 2px;\n  padding-bottom: ", "px;\n  text-align: center;\n"], ["\n  flex: 1 1 auto;\n  color: ", ";\n  margin-top: 2px;\n  padding-bottom: ", "px;\n  text-align: center;\n"])), polished.darken(0.3, darker), extraTight);
var templateObject_1$4, templateObject_2$2, templateObject_3$1, templateObject_4$1, templateObject_5$1, templateObject_6$1, templateObject_7, templateObject_8, templateObject_9, templateObject_10, templateObject_11, templateObject_12, templateObject_13;

function monthName(month) {
    switch (month) {
        case 0:
            return 'january';
        case 1:
            return 'february';
        case 2:
            return 'march';
        case 3:
            return 'april';
        case 4:
            return 'may';
        case 5:
            return 'june';
        case 6:
            return 'july';
        case 7:
            return 'august';
        case 8:
            return 'september';
        case 9:
            return 'october';
        case 10:
            return 'november';
        case 11:
            return 'december';
    }
}
function weekdayName(weekday) {
    switch (weekday) {
        case 0:
            return 'sunday';
        case 1:
            return 'monday';
        case 2:
            return 'tuesday';
        case 3:
            return 'wednesday';
        case 4:
            return 'thursday';
        case 5:
            return 'friday';
        case 6:
            return 'saturday';
    }
}
var isSameDate = function (a, b) {
    return (new Date(a).toISOString().split('T')[0] ==
        new Date(b).toISOString().split('T')[0]);
};
function dateIsSelected(day, dates) {
    if (day == null) {
        return false;
    }
    return Boolean(dates.map(function (_) { return isSameDate(_, day); }).includes(true));
}
function arrayUnique(array) {
    var i = 0;
    var length = array.length;
    for (i; i < length; ++i) {
        var j = i + 1;
        for (j; j < length; ++j) {
            if (array[i] === array[j])
                array.splice(j--, 1);
        }
    }
    return array;
}
function getNewList(dates, selected) {
    if (dates == null) {
        return [selected];
    }
    if (dates.find(function (_) { return isSameDate(_, selected); })) {
        return dates.filter(function (_) { return !isSameDate(_, selected); });
    }
    return arrayUnique(dates.concat([selected]));
}

var Day = React.memo(function Day(_a) {
    var day = _a.day, focused = _a.focused, onClick = _a.onClick, _b = _a.onHover, onHover = _b === void 0 ? noop : _b, _c = _a.onFocus, onFocus = _c === void 0 ? noop : _c, selected = _a.selected, disabled = _a.disabled, lastDayOfMonth = _a.lastDayOfMonth;
    var dayNode = React.useRef(null);
    var hoverValue = lastDayOfMonth || day;
    React.useEffect(function () {
        if (focused && dayNode.current) {
            dayNode.current.focus();
        }
    }, [focused]);
    if (!day) {
        return (React__default.createElement(DayContainer, null,
            React__default.createElement(EmptyDay, null)));
    }
    var handleClick = onClick && !disabled ? onClick.bind(null, day) : noop;
    var today = dates.isSameDay(new Date(), day);
    var date = day.getDate();
    var tabIndex = (focused || selected || today || date === 1) && !disabled ? 0 : -1;
    var ariaLabel = [
        "" + (today ? 'today' : ''),
        dates.Months[day.getMonth()] + " ",
        date + " ",
        "" + day.getFullYear(),
    ].join('');
    return (React__default.createElement(DayContainer, null,
        React__default.createElement(DayStyled, { onFocus: function () { return onFocus(day); }, type: "button", ref: dayNode, tabIndex: tabIndex, onMouseOver: function () { return onHover(hoverValue); }, onClick: handleClick, "aria-label": ariaLabel, "aria-selected": selected, selected: selected, "aria-disabled": disabled, role: "gridcell" }, date),
        selected && React__default.createElement(DayShadowLayer, null)));
});
function noop() { }

var Weekday = React.memo(function Weekday(_a) {
    var label = _a.label, title = _a.title, current = _a.current;
    return (React__default.createElement(WeekdayStyled, { "aria-label": dates.Weekdays[label], current: current }, title.slice(0, 3).toUpperCase()));
});

var WEEKDAYS = [
    dates.Weekdays.Sunday,
    dates.Weekdays.Monday,
    dates.Weekdays.Tuesday,
    dates.Weekdays.Wednesday,
    dates.Weekdays.Thursday,
    dates.Weekdays.Friday,
    dates.Weekdays.Saturday,
];
function Month(_a) {
    var focusedDate = _a.focusedDate, selected = _a.selected, disableDatesBefore = _a.disableDatesBefore, disableDatesAfter = _a.disableDatesAfter, _b = _a.onChange, onChange = _b === void 0 ? noop$1 : _b, _c = _a.onFocus, onFocus = _c === void 0 ? noop$1 : _c, month = _a.month, year = _a.year, weekStartsOn = _a.weekStartsOn;
    var _d;
    var now = new Date();
    var current = now.getMonth() === month && now.getFullYear() === year;
    var weeks = React.useMemo(function () { return dates.getWeeksForMonth(month, year, weekStartsOn); }, [
        month,
        weekStartsOn,
        year,
    ]);
    var weekdays = getWeekdaysOrdered(weekStartsOn).map(function (weekday) { return (React__default.createElement(Weekday, { key: weekday, title: "" + weekdayName(weekday), current: current && new Date().getDay() === weekday, label: weekday })); });
    var handleDateClick = React.useCallback(function (selectedDate) {
        onChange(getNewList(selected, selectedDate));
    }, [onChange, selected]);
    var lastDayOfMonth = React.useMemo(function () { return new Date(year, month + 1, 0); }, [month, year]);
    function renderWeek(day, dayIndex) {
        if (day == null) {
            return React__default.createElement(Day, { key: dayIndex, lastDayOfMonth: lastDayOfMonth });
        }
        var disabled = (disableDatesBefore && dates.isDateBefore(day, disableDatesBefore)) ||
            (disableDatesAfter && dates.isDateAfter(day, disableDatesAfter));
        return (React__default.createElement(Day, { focused: focusedDate && dates.isSameDay(day, focusedDate), day: day, key: dayIndex, onFocus: onFocus, onClick: handleDateClick, selected: selected && dateIsSelected(day, selected), disabled: disabled }));
    }
    var weeksMarkup = weeks.map(function (week, index) { return (React__default.createElement(WeekStyled, { role: "row", key: index }, week.map(renderWeek))); });
    return (React__default.createElement(MonthStyled, { role: "grid" },
        React__default.createElement(Title, null, "" + ((_d = monthName(month)) === null || _d === void 0 ? void 0 : _d.toUpperCase()),
            " ",
            year),
        React__default.createElement(WeekHeadings, { role: "rowheader" }, weekdays),
        React__default.createElement(WeeksContainer, null, weeksMarkup)));
}
function noop$1() { }
function getWeekdaysOrdered(weekStartsOn) {
    var weekDays = __spreadArrays(WEEKDAYS);
    var restOfDays = weekDays.splice(weekStartsOn);
    return __spreadArrays(restOfDays, weekDays);
}

var DatePicker = function (_a) {
    var id = _a.id, selected = _a.selected, month = _a.month, year = _a.year, allowRange = _a.allowRange, multiMonth = _a.multiMonth, disableDatesBefore = _a.disableDatesBefore, disableDatesAfter = _a.disableDatesAfter, _b = _a.weekStartsOn, weekStartsOn = _b === void 0 ? dates.Weekdays.Sunday : _b, onMonthChange = _a.onMonthChange, _c = _a.onChange, onChange = _c === void 0 ? noop$2 : _c;
    // const [hoverDate, setHoverDate] = useState<Date | undefined>(undefined);
    var _d = React.useState(undefined), focusDate = _d[0], setFocusDate = _d[1];
    React.useEffect(function () {
        setFocusDate(undefined);
    }, [selected]);
    var handleFocus = React.useCallback(function (date) {
        setFocusDate(date);
    }, []);
    var handleDateSelection = React.useCallback(function (dates) {
        onChange(dates);
    }, [onChange]);
    var handleMonthChangeClick = React.useCallback(function (month, year) {
        if (!onMonthChange) {
            return;
        }
        setFocusDate(undefined);
        onMonthChange(month, year);
    }, [onMonthChange]);
    var showNextYear = dates.getNextDisplayYear(month, year);
    var showNextMonth = dates.getNextDisplayMonth(month);
    var showNextToNextYear = dates.getNextDisplayYear(showNextMonth, showNextYear);
    var showNextToNextMonth = dates.getNextDisplayMonth(showNextMonth);
    var showPreviousYear = dates.getPreviousDisplayYear(month, year);
    var showPreviousMonth = dates.getPreviousDisplayMonth(month);
    var previousMonthName = monthName(showPreviousMonth);
    var nextMonth = multiMonth
        ? monthName(showNextToNextMonth)
        : monthName(showNextMonth);
    var nextYear = multiMonth ? showNextToNextYear : showNextYear;
    var monthIsSelected = React.useMemo(function () { return selected; }, [selected]);
    var secondDatePicker = multiMonth ? (React__default.createElement(Month, { onFocus: handleFocus, focusedDate: focusDate, month: showNextMonth, year: showNextYear, selected: monthIsSelected, onChange: handleDateSelection, disableDatesBefore: disableDatesBefore, disableDatesAfter: disableDatesAfter, allowRange: allowRange, weekStartsOn: weekStartsOn })) : null;
    return (React__default.createElement(DatePickerContainer, { id: id },
        React__default.createElement(Header, null,
            React__default.createElement(Button, { plain: true, size: "slim", accessibilityLabel: previousMonthName + " / " + showPreviousYear, onClick: function () {
                    return handleMonthChangeClick(showPreviousMonth, showPreviousYear);
                } }, "\u2190"),
            React__default.createElement(Button, { plain: true, size: "slim", accessibilityLabel: nextMonth + " / " + nextYear, onClick: function () { return handleMonthChangeClick(showNextMonth, showNextYear); } }, "\u2192")),
        React__default.createElement(MonthContainer, null,
            React__default.createElement(Month, { onFocus: handleFocus, focusedDate: focusDate, month: month, year: year, selected: selected, onChange: handleDateSelection, disableDatesBefore: disableDatesBefore, disableDatesAfter: disableDatesAfter, allowRange: allowRange, weekStartsOn: weekStartsOn }),
            secondDatePicker)));
};
function noop$2() { }

/**
 * Returns a stateful value, and a set of memoized functions to toggle it,
 * set it to true and set it to false
 */
function useToggle(initialState) {
    var _a = React.useState(initialState), value = _a[0], setState = _a[1];
    return {
        value: value,
        toggle: React.useCallback(function () { return setState(function (state) { return !state; }); }, []),
        setTrue: React.useCallback(function () { return setState(true); }, []),
        setFalse: React.useCallback(function () { return setState(false); }, []),
    };
}

function Choice(_a) {
    // const className = classNames(
    //   styles.Choice,
    //   labelHidden && styles.labelHidden,
    //   disabled && styles.disabled
    // );
    var id = _a.id, label = _a.label, disabled = _a.disabled, error = _a.error, children = _a.children, labelHidden = _a.labelHidden, helpText = _a.helpText, onClick = _a.onClick, onMouseOut = _a.onMouseOut, onMouseOver = _a.onMouseOver;
    // Deleted
    // <span className={styles.Control}>{children}</span>
    // <span className={styles.Label}>{label}</span>
    var labelMarkup = (React__default.createElement("label", { htmlFor: id, onClick: onClick, onMouseOver: onMouseOver, onMouseOut: onMouseOut },
        React__default.createElement("span", null, children),
        React__default.createElement("span", null, label)));
    // Deleted
    // className={styles.HelpText}
    var helpTextMarkup = helpText ? (React__default.createElement("div", { id: helpTextID(id) }, helpText)) : null;
    // Deleted
    // className={styles.Descriptions}
    var descriptionMarkup = helpTextMarkup ? React__default.createElement("div", null, helpTextMarkup) : null;
    return descriptionMarkup ? (React__default.createElement("div", null,
        labelMarkup,
        descriptionMarkup)) : (labelMarkup);
}
function helpTextID(id) {
    return id + "HelpText";
}

var RadioButton = function (_a) {
    var ariaDescribedByProp = _a.ariaDescribedBy, label = _a.label, labelHidden = _a.labelHidden, helpText = _a.helpText, checked = _a.checked, disabled = _a.disabled, onChange = _a.onChange, onFocus = _a.onFocus, onBlur = _a.onBlur, idProp = _a.id, nameProp = _a.name, value = _a.value;
    var id = idProp || '';
    var name = nameProp || id;
    var inputNode = React.useRef(null);
    var _b = React.useState(false), keyFocused = _b[0], setKeyFocused = _b[1];
    var _c = useToggle(false), handleMouseOver = _c.setTrue, handleMouseOut = _c.setFalse;
    var handleKeyUp = function () {
        !keyFocused && setKeyFocused(true);
    };
    var handleBlur = function () {
        onBlur && onBlur();
        setKeyFocused(false);
    };
    function handleChange(_a) {
        var currentTarget = _a.currentTarget;
        onChange && onChange(currentTarget.checked, id);
    }
    var describedBy = [];
    if (helpText) {
        describedBy.push(helpTextID(id));
    }
    if (ariaDescribedByProp) {
        describedBy.push(ariaDescribedByProp);
    }
    var ariaDescribedBy = describedBy.length
        ? describedBy.join(' ')
        : undefined;
    // const inputClassName = classNames(
    //   styles.Input,
    //   newDesignLanguage && keyFocused && styles.keyFocused
    // );
    // const wrapperClassName = classNames(
    //   styles.RadioButton,
    //   newDesignLanguage && styles.newDesignLanguage
    // );
    // const backdropClassName = classNames(
    //   styles.Backdrop,
    //   mouseOver && styles.hover
    // );
    // Deleted
    // className={inputClassName}
    //
    return (React__default.createElement(Choice, { label: label, labelHidden: labelHidden, disabled: disabled, id: id, helpText: helpText, onMouseOver: handleMouseOver, onMouseOut: handleMouseOut },
        React__default.createElement("span", null,
            React__default.createElement("input", { id: id, name: name, value: value, type: "radio", checked: checked, disabled: disabled, onChange: handleChange, onFocus: onFocus, onKeyUp: handleKeyUp, onBlur: handleBlur, "aria-describedby": ariaDescribedBy, ref: inputNode }))));
};

exports.Button = Button;
exports.DatePicker = DatePicker;
exports.RadioButton = RadioButton;
exports.Stack = Stack$1;
exports.TextField = TextField;
